@@ -71,7 +71,8 @@ class DaemonProcess(object):
             'grease_data.execution.server': ObjectId(self.ioc.getConfig().NodeIdentity),
             'grease_data.execution.commandSuccess': False,
             'grease_data.execution.executionSuccess': False,
-            'grease_data.execution.failures': {'$lt': 6}
+            'grease_data.execution.failures': {'$lt': 6},
+            '$or': [{'grease_data.execution.returnData.no_retry': {'$exists': False}}, {'grease_data.execution.returnData.no_retry': False}]
         })
         # Get Node Information
         Node = self.ioc.getCollection('JobServer').find_one({'_id': ObjectId(self.ioc.getConfig().NodeIdentity)})
@@ -113,11 +114,29 @@ class DaemonProcess(object):
         if not self.contextManager['jobs'].get(job.get('_id')):
             # New Job to run
             if isinstance(job.get('configuration'), bytes):
-                conf = job.get('configuration').decode()
+                conf = self.conf.get_config(job.get('configuration').decode())
             else:
-                conf = job.get('configuration')
-            inst = self.impTool.load(self.conf.get_config(conf).get('job', ''))
+                conf = self.conf.get_config(job.get('configuration'))
+            # Honor a config's retry maximum if present
+            if conf.get('retry_maximum') and \
+                job.get('grease_data', {}).get('execution', {}).get('failures', 0) - 1 >= conf.get("retry_maximum", 5):
+                self.ioc.getLogger().info(
+                    "Job has hit its retry maximum of {0}".format(conf.get('retry_maximum', 5)),
+                    additional=job
+                )
+                JobCollection.update_one(
+                    {'_id': ObjectId(job['_id'])},
+                    {
+                        '$set': {
+                            'grease_data.execution.returnData.no_retry': True
+                        }
+                    }
+                )
+                return
+
+            inst = self.impTool.load(conf.get('job', ''))
             if inst and isinstance(inst, Command):
+                inst.failures = job.get("grease_data", {}).get("execution", {}).get("failures")
                 inst.ioc.getLogger().foreground = self.ioc.getLogger().foreground
                 thread = threading.Thread(
                     target=inst.safe_execute,
@@ -227,7 +246,7 @@ class DaemonProcess(object):
                     return
                 inst.ioc.getLogger().foreground = self.ioc.getLogger().foreground
                 thread = threading.Thread(
-                    target=inst.execute,
+                    target=inst.safe_execute,
                     name="GREASE DAEMON PROTOTYPE [{0}]".format(prototype)
                 )
                 thread.daemon = True
